@@ -36,29 +36,37 @@ class InferDatetime:
         }
         datetime_dict = {
             # 1930-08-05 12:00:05
-            "^\\d{4}-\\d{1,2}-\\d{1,2}$": {"C89": "%Y-%m-%d %H:%M:%S ", 'snowflake': 'yyyy-MM-dd hh:mi:ss',
-                                           'java': 'yyyy-MM-dd hh:mm:ss'},
+            "^\\d{4}-\\d{1,2}-\\d{1,2} \\d{2}:\\d{2}:\\d{2}$": {"C89": "%Y-%m-%d %H:%M:%S",
+                                                                'snowflake': 'yyyy-MM-dd hh:mi:ss',
+                                                                'java': 'yyyy-MM-dd hh:mm:ss'},
             # 08-05-30 12:00:05
-            "^\\d{1,2}-\\d{1,2}-\\d{2}$": {"C89": "%m-%d-%y %H:%M:%S", 'snowflake': 'mm-dd-yy hh:mi:ss',
-                                           'java': 'MM-dd-yy hh:mm:ss'},
+            "^\\d{1,2}-\\d{1,2}-\\d{2}$ \\d{2}:\\d{2}:\\d{2}$": {"C89": "%m-%d-%y %H:%M:%S",
+                                                                 'snowflake': 'mm-dd-yy hh:mi:ss',
+                                                                 'java': 'MM-dd-yy hh:mm:ss'},
             # 08-05-1930 12:00:05
-            "^\\d{1,2}-\\d{1,2}-\\d{4}$": {"C89": "%m-%d-%Y %H:%M:%S", 'snowflake': 'mm-dd-yyyy hh:mi:ss',
-                                           'java': 'MM-dd-yyyy hh:mm:ss'},
+            "^\\d{1,2}-\\d{1,2}-\\d{4}$ \\d{2}:\\d{2}:\\d{2}$": {"C89": "%m-%d-%Y %H:%M:%S",
+                                                                 'snowflake': 'mm-dd-yyyy hh:mi:ss',
+                                                                 'java': 'MM-dd-yyyy hh:mm:ss'},
             # 8-5-30 12:00:05
-            "^\\d{1}-\\d{1}-\\d{2}$": {"C89": "%-m/%-d/%y %H:%M:%S", 'snowflake': 'mm-dd-yy hh:mi:ss',
-                                       'java': 'M-d-yy hh:mm:ss'},
+            "^\\d{1}-\\d{1}-\\d{2}$ \\d{2}:\\d{2}:\\d{2}$": {"C89": "%-m/%-d/%y %H:%M:%S",
+                                                             'snowflake': 'mm-dd-yy hh:mi:ss',
+                                                             'java': 'M-d-yy hh:mm:ss'},
             # 1930/08/05 12:00:05
-            "^\\d{4}/\\d{1,2}/\\d{1,2}$": {"C89": "%Y/%m/%d %H:%M:%S", 'snowflake': 'yyyy/MM/dd hh:mi:ss',
-                                           'java': 'yyyy/MM/dd hh:mm:ss'},
+            "^\\d{4}/\\d{1,2}/\\d{1,2} \\d{2}:\\d{2}:\\d{2}$": {"C89": "%Y/%m/%d %H:%M:%S",
+                                                                'snowflake': 'yyyy/MM/dd hh:mi:ss',
+                                                                'java': 'yyyy/MM/dd hh:mm:ss'},
             # 08/05/30 12:00:05
-            "^\\d{1,2}/\\d{1,2}/\\d{2}$": {"C89": "%m/%d/%y %H:%M:%S", 'snowflake': 'MM /dd/yy hh:mi:ss',
-                                           'java': 'MM/dd/yy hh:mm:ss'},
+            "^\\d{1,2}/\\d{1,2}/\\d{2} \\d{2}:\\d{2}:\\d{2}$": {"C89": "%m/%d/%y %H:%M:%S",
+                                                                'snowflake': 'MM /dd/yy hh:mi:ss',
+                                                                'java': 'MM/dd/yy hh:mm:ss'},
             # 08/05/1930 12:00:05
-            "^\\d{1,2}/\\d{1,2}/\\d{4}$": {"C89": "%m-%d-%Y %H:%M:%S", 'snowflake': 'MM/dd/yyyy hh:mi:ss',
-                                           'java': 'MM/dd/yyyy hh:mm:ss'},
+            "^\\d{1,2}/\\d{1,2}/\\d{4} \\d{2}:\\d{2}:\\d{2}$": {"C89": "%m-%d-%Y %H:%M:%S",
+                                                                'snowflake': 'MM/dd/yyyy hh:mi:ss',
+                                                                'java': 'MM/dd/yyyy hh:mm:ss'},
             # 8/5/30 12:00:05
-            "^\\d{1}/\\d{1}/\\d{2}$": {"C89": "%-m/%-d/%y %H:%M:%S", 'snowflake': 'MM/dd/yy hh:mi:ss',
-                                       'java': 'M/d/yy hh:mm:ss'},
+            "^\\d{1}/\\d{1}/\\d{2} \\d{2}:\\d{2}:\\d{2}$": {"C89": "%-m/%-d/%y %H:%M:%S",
+                                                            'snowflake': 'MM/dd/yy hh:mi:ss',
+                                                            'java': 'M/d/yy hh:mm:ss'},
             # 2019-11-27T12:00:05.000Z
             "^\\d{4}-\\d{1,2}-\\d{1,2}T\\d{2}:\\d{2}:\\d{2}.\\d{3}Z$": {"C89": "%Y-%m-%dT%H:%M:%S.%fZ",
                                                                         'snowflake': 'yyyy-MM-ddTHH:mm:ss.SSZ',
@@ -68,8 +76,8 @@ class InferDatetime:
         if Evaluator(series).series_match(generic_date_pattern):
             # Have this column time ?
             formats_dict = datetime_dict if Evaluator(series).series_contains(hour_pattern) else dates_dict
-            format_result = {'formats': [date_format.get(return_format) for (re_exp, date_format) in formats_dict.items() if
-                                         Evaluator(series).series_contains(re_exp)], 'type': 'datetime'}
+            format_result = {
+                'formats': [date_format.get(return_format) for (re_exp, date_format) in formats_dict.items() if
+                            Evaluator(series).series_contains(re_exp)], 'type': 'datetime'}
             return format_result
-
         return {}
